Package: Lheuristic
Title: Detection of scatterplots with L-shaped pattern
Version: 1.2.0
Authors@R: c(
    person("Sanchez Pla", "Alex", email ="asanchez@ub.edu", role = c("aut", "cre"),
  comment = c(ORCID = "0000-0002-8673-7737")),
    person("Miro Cau", "Berta", email = "berta.miro@vhir.org", role = "aut", ,
  comment = c(ORCID = "0000-0001-6049-8697")))
Description: The Lheuristic package identifies scatterpots that
    follow and L-shaped, negative distribution. It can be used
    to identify genes regulated by methylation by integration of
    an expression and a methylation array. The package uses two
    different methods to detect expression and methyaltion L-
    shapped scatterplots. The parameters can be changed to
    detect other scatterplot patterns.
License: MIT + file LICENSE
Depends: R (>= 4.4.0)
biocViews: DNAMethylation, StatisticalMethod, MethylationArray
Imports: Hmisc, stats, energy, grDevices, graphics, utils,
        MultiAssayExperiment, ggplot2, ggpubr
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
URL: https://github.com/ASPresearch/Lheuristic
BugReports: https://github.com/ASPresearch/Lheuristic/issues
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: false
RoxygenNote: 7.3.2
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/Lheuristic
git_branch: RELEASE_3_22
git_last_commit: ef97be8
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 04:44:00 UTC; biocbuild
Author: Sanchez Pla Alex [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8673-7737>),
  Miro Cau Berta [aut] (ORCID: <https://orcid.org/0000-0001-6049-8697>)
Maintainer: Sanchez Pla Alex <asanchez@ub.edu>
