# Generated by roxygen2: do not edit by hand

export(binScore)
export(calcFreqs)
export(checkPairing)
export(correlationSelection)
export(lhCreateMAE)
export(matCorrs)
export(messageTitle)
export(numScore)
export(plotGeneByName)
export(plotGeneSel)
export(plotGenesMat)
export(scoreGenesMat)
export(toReqMat)
import(Hmisc)
import(ggplot2)
import(ggpubr)
import(stats)
importFrom(MultiAssayExperiment,ExperimentList)
importFrom(MultiAssayExperiment,MultiAssayExperiment)
importFrom(MultiAssayExperiment,assay)
importFrom(MultiAssayExperiment,experiments)
importFrom(energy,dcor)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(graphics,abline)
