The Lheuristic package identifies scatterpots that
    follow and L-shaped, negative distribution. It can be used
    to identify genes regulated by methylation by integration of
    an expression and a methylation array. The package uses two
    different methods to detect expression and methyaltion L-
    shapped scatterplots. The parameters can be changed to
    detect other scatterplot patterns.