#' Expression data matrix obtained from TCGA, TCGA-COAD dataset
#'
#' A mxn matrix containing normalized gene expressions from TCGA
#'
#' @docType data
#'
#' @usage data(TCGAexpression)
#'
#' @return data matrix with gene expression data
#'
#' @source \url{TCGA.org}
"TCGAexpression"

#' Methylation data matrix obtained from TCGA, TCGA-COAD dataset
#'
#' A mxn matrix containing normalized methylation values from TCGA
#'
#' @docType data
#'
#' @usage data(TCGAmethylation)
#'
#' @return data matrix with gene methylation data
#'
#' @source \url{TCGA.org}
"TCGAmethylation"
